#!/bin/bash
#
# bcm-runtime:bin/bcm-api/libreelec-api.sh
# prepare-raspbian-sd:bin/api/libreelec-api.sh
#
if [ "$( type -t echofatal )" != 'function' ] ; then
  echo 'https://git.cclaude.rocks/bash-apis/bash-common-api is required: Function echofatal not found.' >&2
  exit 100
fi

# To update this URL see:
#   Creator::releasesUrl
# in
#   https://github.com/LibreELEC/usb-sd-creator/blob/master/creator.cpp
declare -gr __LIBREELEC_RELEASES_BASE_URL__='https://releases.libreelec.tv/'

# To update this URL see:
#   Creator::downloadReleases()
# in
#   https://github.com/LibreELEC/usb-sd-creator/blob/master/creator.cpp
declare -gr __LIBREELEC_RELEASES_JSON_URL__="${__LIBREELEC_RELEASES_BASE_URL__}releases.json"

# https is redirect to http ! (so we can't trust content)
#eclare -gr __LIBREELEC_RELEASES_JSON_URL__='https://releases.libreelec.tv/releases.json' # is a redirect to http !

#eclare -gr __LIBREELEC_DOWNLOAD_URL_BASE__='https://archive.libreelec.tv' No more available !
declare -gr __LIBREELEC_DOWNLOAD_URL_BASE__="${__LIBREELEC_RELEASES_BASE_URL__}"

#curl -L https://releases.libreelec.tv/releases.json | jq --sort-keys 'to_entries[] | .value | .project | keys[]'

function get_libreelec_hardware_type_json {
  curl -L "${__LIBREELEC_RELEASES_JSON_URL__}" | jq -c '[ .[] | .project | keys[] ]' || return $?
}

function get_libreelec_versions_json {
  local -r hardware_type="$1" # 'RPi2.arm' / 'RPi4.arm'
  local -r file_type="$2"     # 'file' / 'image'

  (
    set -x
    curl -L --silent --show-error "${__LIBREELEC_RELEASES_JSON_URL__}" |
      jq -c \
        --arg 'filter' "LibreELEC-${hardware_type}-(?<xorder>[[:digit:]]+\\.[[:digit:]]+\\.[[:digit:]]+)\\..*" \
        --arg 'hard' "${hardware_type}" \
        --arg 'type' "${file_type}" \
        '[ to_entries[].value.project[$hard] // empty | .releases[] | .[$type] | . + (.name | capture($filter)) ] | sort_by( .xorder | split(".") | map(tonumber) )'
  ) || return $?
  #
  # Result:
  # [
  #   {"name":"LibreELEC-RPi2.arm-11.0.0.tar","sha256":"7f8f99814f641384cbfb129b0ae86d622024f9748db378ef4db686992e69cf8f","size":"136110080","xorder":"11.0.0"}
  #   {"name":"LibreELEC-RPi2.arm-11.0.1.tar","sha256":"49724b222b9559c8751c0bc7874fdf38c95c8f7f23f53ea65719404443b20258","size":"136171520","xorder":"11.0.1"}
  # ]
  #
  # jq -c --arg filter 'LibreELEC-RPi2.arm-(?<xorder>[[:digit:]]+\.[[:digit:]]+\.[[:digit:]]+)\..*' --arg hard RPi2.arm --arg type file '[ to_entries[].value.project[$hard] // empty | .releases[] | .[$type] | . + (.name | capture($filter)) ] | sort_by( .xorder | split(".") | map(tonumber) )'
  #
}

function get_libreelec_update_versions_json {
  local -r hardware_type="$1" # 'RPi2.arm' / 'RPi4.arm'

  get_libreelec_versions_json "${hardware_type}" 'file' || return $?
}

function get_libreelec_last_update_json {
  local -r hardware_type="$1"

  get_libreelec_update_versions_json "${hardware_type}" | jq -c 'last' || return $?
}

function get_libreelec_image_versions_json {
  local -r hardware_type="$1" # 'RPi2.arm' / 'RPi4.arm'

  get_libreelec_versions_json "${hardware_type}" 'image' || return $?
}

function get_libreelec_last_image_json {
  local -r hardware_type="$1" # 'RPi2.arm' / 'RPi4.arm'

  get_libreelec_image_versions_json "${hardware_type}" | jq -c 'last' || return $?
}

function get_libreelec_name_from_json {
  local -r json="$1"

  jq -r '.name' <<<"${json}" || return $?
}

function get_libreelec_sha256_from_json {
  local -r json="$1"

  jq -r '.sha256' <<<"${json}" || return $?
}

function get_libreelec_size_from_json {
  local -r json="$1"

  jq -r '.size' <<<"${json}" || return $?
}

function get_libreelec_url {
  local -r path="$1"

  echo "${__LIBREELEC_DOWNLOAD_URL_BASE__}/${path}"
}
